/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.llap.counters;

import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

import org.apache.tez.common.counters.TezCounters;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Maintains references to tez counters
 */
public class FragmentCountersMap {
  private static final Logger LOG = LoggerFactory.getLogger(FragmentCountersMap.class);
  private static final ConcurrentMap<String, TezCounters> perFragmentCounters = new ConcurrentHashMap<>();

  public static void registerCountersForFragment(String identifier, TezCounters tezCounters) {
    if (perFragmentCounters.putIfAbsent(identifier, tezCounters) != null) {
      LOG.warn("Not registering duplicate counters for fragment with tez identifier string=" +
          identifier);
    }
  }

  public static TezCounters getCountersForFragment(String identifier) {
    return perFragmentCounters.get(identifier);
  }

  public static void unregisterCountersForFragment(String identifier) {
    perFragmentCounters.remove(identifier);
  }
}
