/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.serde2.objectinspector.primitive;

import org.apache.hadoop.hive.serde2.typeinfo.TypeInfoFactory;
import org.apache.hadoop.io.FloatWritable;

/**
 * A JavaFloatObjectInspector inspects a Java Float Object.
 */
public class JavaFloatObjectInspector extends
    AbstractPrimitiveJavaObjectInspector implements
    SettableFloatObjectInspector {

  JavaFloatObjectInspector() {
    super(TypeInfoFactory.floatTypeInfo);
  }

  @Override
  public Object getPrimitiveWritableObject(Object o) {
    return o == null ? null : new FloatWritable(((Float) o).floatValue());
  }

  @Override
  public float get(Object o) {
    return ((Float) o).floatValue();
  }

  @Override
  public Object create(float value) {
    return Float.valueOf(value);
  }

  @Override
  public Object set(Object o, float value) {
    return Float.valueOf(value);
  }
}
